.. _scientific_background:


Scientific Background
=====================

A section that provides a high-level overview of the scientific background of the project. This section has been written in a way that is accessible to a general audience, and to provide context for the more detailed scientific guides that follow.


.. admonition:: Note

  This section is a work in progress and will be expanded upon in future updates.


.. toctree::
    :maxdepth: 2

    science/guide1/index
    science/guide2/index
